@@ -13,6 +13,7 @@
  *******************************************************************************/
 package org.eclipse.ui.internal.editors.text;
 
+import java.text.Collator;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Comparator;
@@ -20,8 +21,6 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Set;
 
-import com.ibm.icu.text.Collator;
-
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
@@ -244,7 +243,6 @@ class AnnotationsConfigurationBlock implements IPreferenceConfigurationBlock {
 		gd= new GridData(GridData.FILL_HORIZONTAL);
 		gd.horizontalAlignment= GridData.BEGINNING;
 		gd.horizontalSpan= 2;
-		gd.horizontalIndent= 20;
 		fShowInVerticalRulerCheckBox.setLayoutData(gd);
 
 		fShowInOverviewRulerCheckBox= new Button(optionsComposite, SWT.CHECK);
@@ -252,14 +250,12 @@ class AnnotationsConfigurationBlock implements IPreferenceConfigurationBlock {
 		gd= new GridData(GridData.FILL_HORIZONTAL);
 		gd.horizontalAlignment= GridData.BEGINNING;
 		gd.horizontalSpan= 2;
-		gd.horizontalIndent= 20;
 		fShowInOverviewRulerCheckBox.setLayoutData(gd);
 
 		fShowInTextCheckBox= new Button(optionsComposite, SWT.CHECK);
 		fShowInTextCheckBox.setText(TextEditorMessages.AnnotationsConfigurationBlock_showInText);
 		gd= new GridData(GridData.FILL_HORIZONTAL);
 		gd.horizontalAlignment= GridData.BEGINNING;
-		gd.horizontalIndent= 20;
 		fShowInTextCheckBox.setLayoutData(gd);
 
 
@@ -278,7 +274,6 @@ class AnnotationsConfigurationBlock implements IPreferenceConfigurationBlock {
 		label.setText(TextEditorMessages.AnnotationsConfigurationBlock_color);
 		gd= new GridData();
 		gd.horizontalAlignment= GridData.BEGINNING;
-		gd.horizontalIndent= 20;
 		label.setLayoutData(gd);
 
 		fAnnotationForegroundColorEditor= new ColorSelector(optionsComposite);
@@ -438,8 +433,7 @@ class AnnotationsConfigurationBlock implements IPreferenceConfigurationBlock {
 		if (!(data instanceof String))
 			return;
 
-		for (int i= 0; i < fListModel.length; i++) {
-			final ListItem element= fListModel[i];
+		for (ListItem element : fListModel) {
 			if (data.equals(element.label)) {
 				final Control control= fAnnotationTypeViewer.getControl();
 				control.getDisplay().asyncExec(() -> {
@@ -646,8 +640,7 @@ class AnnotationsConfigurationBlock implements IPreferenceConfigurationBlock {
 	public void dispose() {
 		ImageRegistry registry= EditorsPlugin.getDefault().getImageRegistry();
 
-		for (Iterator<String> it= fImageKeys.iterator(); it.hasNext();) {
-			String string= it.next();
+		for (String string : fImageKeys) {
 			registry.remove(string);
 		}
 
@@ -690,8 +683,7 @@ class AnnotationsConfigurationBlock implements IPreferenceConfigurationBlock {
 			// set selection
 			if (selection == null) {
 				String val= item.textStyleKey == null ? SQUIGGLES[1] : fStore.getString(item.textStyleKey);
-				for (Iterator<String[]> iter= list.iterator(); iter.hasNext();) {
-					String[] elem= iter.next();
+				for (String[] elem : list) {
 					if (elem[1].equals(val)) {
 						selection= elem;
 						break;
